# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`groundplex`](#groundplex): Configures a Snaplogic on-premise execution engine.
* [`groundplex::config`](#groundplexconfig): Performs zone creation and update operations. Internal class
* [`groundplex::install`](#groundplexinstall): Install the snaplogic-sidekick package
* [`groundplex::service`](#groundplexservice): Internal class which ensures the groundplex process is running

### Data types

* [`Groundplex::PuppetUrl`](#groundplexpuppeturl): Matches puppet:// paths
* [`Groundplex::SapMessageServer`](#groundplexsapmessageserver)
* [`Groundplex::Sapjco3Config`](#groundplexsapjco3config): Content definitions for SAP Java Connector library files.
* [`Groundplex::ServerType`](#groundplexservertype): List of valid items to specify in /etc/security/limits.conf
* [`Groundplex::SourceUrl`](#groundplexsourceurl): matches any valid URL type

## Classes

### <a name="groundplex"></a>`groundplex`

Configures a Snaplogic on-premise execution engine.

#### Parameters

The following parameters are available in the `groundplex` class:

* [`service_user`](#service_user)
* [`service_group`](#service_group)
* [`server_type`](#server_type)
* [`slpropz_source`](#slpropz_source)
* [`package`](#package)
* [`array_msg_servers`](#array_msg_servers)
* [`sapjco_config`](#sapjco_config)

##### <a name="service_user"></a>`service_user`

Data type: `String`

Username of the snaplogic service account.
Note that this is created by the installation of the agent RPM.

Default value: `'snapuser'`

##### <a name="service_group"></a>`service_group`

Data type: `String`

Group name of the snaplogic service user
Note that this is created by the installation of the agent RPM.

Default value: `'snapuser'`

##### <a name="server_type"></a>`server_type`

Data type: `Groundplex::ServerType`

Determines the role this node will perform in the on-premise environment.
Currently this is limited to the following:
  - `JCC` - An execution engine node which performs actual pipeline work
  - `FeedMaster` - Manages the data feed for Ultra Pipelines

Default value: `'JCC'`

##### <a name="slpropz_source"></a>`slpropz_source`

Data type: `Stdlib::HTTPSUrl`

Full URL including API parameters to the snaplogic configuration file
associated with this snaplex. This is retrieved from the Downloads tab of
the Snaplex Settings dialog in Manager -> Project Spaces -> shared ->
Snaplexes.

##### <a name="package"></a>`package`

Data type: `String`

Name of the snaplogic agent package. Note that this assumes the presence of
a custom repo / mirror which also hosts this file.

Default value: `'snaplogic-sidekick'`

##### <a name="array_msg_servers"></a>`array_msg_servers`

Data type: `Array[Groundplex::SapMessageserver]`

List of SAP ms server intances which should be added to the
/etc/services file on this groundplex host.

Default value: `[]`

##### <a name="sapjco_config"></a>`sapjco_config`

Data type: `Optional[Groundplex::Sapjco3Config]`



Default value: ``undef``

### <a name="groundplexconfig"></a>`groundplex::config`

Performs zone creation and update operations. Internal class

#### Parameters

The following parameters are available in the `groundplex::config` class:

* [`server_type`](#server_type)
* [`service_user`](#service_user)
* [`service_group`](#service_group)
* [`slpropz_source`](#slpropz_source)
* [`array_msg_servers`](#array_msg_servers)

##### <a name="server_type"></a>`server_type`

Data type: `Groundplex::ServerType`



Default value: `$groundplex::server_type`

##### <a name="service_user"></a>`service_user`

Data type: `String`



Default value: `$groundplex::service_user`

##### <a name="service_group"></a>`service_group`

Data type: `String`



Default value: `$groundplex::service_group`

##### <a name="slpropz_source"></a>`slpropz_source`

Data type: `Stdlib::HTTPSUrl`



Default value: `$groundplex::slpropz_source`

##### <a name="array_msg_servers"></a>`array_msg_servers`

Data type: `Array[Groundplex::SapMessageServer]`



Default value: `$groundplex::array_msg_servers`

### <a name="groundplexinstall"></a>`groundplex::install`

Install the snaplogic-sidekick package

#### Parameters

The following parameters are available in the `groundplex::install` class:

* [`package`](#package)
* [`sapjco_config`](#sapjco_config)

##### <a name="package"></a>`package`

Data type: `String`



Default value: `$groundplex::package`

##### <a name="sapjco_config"></a>`sapjco_config`

Data type: `Optional[Groundplex::Sapjco3Config]`



Default value: ``undef``

### <a name="groundplexservice"></a>`groundplex::service`

Internal class which ensures the groundplex process is running

## Data types

### <a name="groundplexpuppeturl"></a>`Groundplex::PuppetUrl`

Matches puppet:// paths

Alias of

```puppet
Pattern[/(?i:^puppet?:\/\/)/]
```

### <a name="groundplexsapmessageserver"></a>`Groundplex::SapMessageServer`

The Groundplex::SapMessageServer data type.

Alias of

```puppet
Struct[=>]
```

#### Parameters

The following parameters are available in the `Groundplex::SapMessageServer` data type:

* [`sid`](#sid)
* [`instance_class`](#instance_class)
* [`number`](#number)
* [`port_override`](#port_override)

##### <a name="sid"></a>`sid`

Matches an SAP instance number

##### <a name="instance_class"></a>`instance_class`

Used to determine the port set to use for the instance alias

##### <a name="number"></a>`number`

Two digit instance number (e.g. 01) which is appended to the port prefix
determined from the instance class.

##### <a name="port_override"></a>`port_override`

Used in exceptional cases to override the port calculation

### <a name="groundplexsapjco3config"></a>`Groundplex::Sapjco3Config`

Content definitions for SAP Java Connector library files.

Alias of

```puppet
Struct[=>]
```

#### Parameters

The following parameters are available in the `Groundplex::Sapjco3Config` data type:

* [`source`](#source)
* [`sha256`](#sha256)

##### <a name="source"></a>`source`

Some form of URL to a copy of the libsapjco3.so library.

##### <a name="sha256"></a>`sha256`

A sha256 hash matching the content of the file referenced by $source.

### <a name="groundplexservertype"></a>`Groundplex::ServerType`

List of valid items to specify in /etc/security/limits.conf

Alias of

```puppet
Enum['JCC', 'FeedMaster']
```

### <a name="groundplexsourceurl"></a>`Groundplex::SourceUrl`

matches any valid URL type

Alias of

```puppet
Variant[Stdlib::Httpurl, Stdlib::Httpsurl, Groundplex::PuppetUrl]
```

